#!/usr/bin/env python
# coding=utf-8
"""Installation script for EarthDiagnostics package"""

from os import path

from setuptools import setup, find_packages

here = path.abspath(path.dirname(__file__))

# Get the version number from the relevant file
with open(path.join(here, "VERSION")) as f:
    version = f.read().strip()


REQUIREMENTS = {
    "setup": [
        "pyproj",
        'pytest-runner',
        'setuptools_scm',
    ],
    "install": [
        "bscearth.utils",
        "cdo>=1.3.4",
        "cfgrib",
        "dask[array]",
        "diagonals>=0.3.2",
        "netCDF4",
        "nco>=0.0.3",
        "numba",
        "numpy",
        "psutil",
        "openpyxl",
        "scitools-iris>=2.4",
        "six",
        "xxhash",
    ],
    "test": [
        "mock",
        'pytest>=3.9',
        'pytest-cov',
        'pytest-env',
        'pytest-flake8',
        'pytest-html',
        'pytest-metadata>=1.5.1',
    ],
}

setup(
    name="earthdiagnostics",
    license="GNU GPL v3",
    platforms=["GNU/Linux Debian"],
    version=version,
    description="EarthDiagnostics",
    author="BSC-CNS Earth Sciences Department",
    author_email="javier.vegas@bsc.es",
    url="http://www.bsc.es/projects/earthsciences/autosubmit/",
    keywords=["climate", "weather", "diagnostic"],
    setup_requires=REQUIREMENTS["setup"],
    install_requires=REQUIREMENTS["install"],
    tests_requires=REQUIREMENTS["test"],
    extras_require={"develop": REQUIREMENTS["test"], },
    packages=find_packages(),
    include_package_data=True,
    scripts=["bin/earthdiags"],
)
